@@ -6,7 +6,7 @@ Created on 27/06/2014
 import sys, types, inspect, functools
 from importlib import import_module
 
-__version__ = 1.5
+__version__ = 1.6
 
 class TypeCheckError(Exception): 
     pass
@@ -29,6 +29,8 @@ def _resolve_type(obj):
         return NotImplementedType
     elif obj in (True, False):
         return bool
+    elif obj.__class__ is tuple:
+        return tuple([_resolve_type(t) for t in obj])
     elif obj.__class__ is str and '.' in obj:
         pkg, cls = obj.rsplit('.', 1)
         return getattr(import_module(pkg), cls)
@@ -53,7 +55,7 @@ def _typecheck(f):
             argtype = _resolve_type(f.__annotations__.get(name, NoType))
 
             # Only check if annotation exists and it is as a type
-            if isinstance(argtype, type):
+            if isinstance(argtype, (type, tuple)):
                 # First len(args) are positional, after that keywords
                 if i < len(args) and not isinstance(args[i], argtype):
                     raise TypeCheckError(arg_error_fmt.format(name, argtype, args[i].__class__))
@@ -63,7 +65,7 @@ def _typecheck(f):
         result = f(*args, **kws)
         returntype = _resolve_type(f.__annotations__.get('return', NoType))
         
-        if isinstance(returntype, type) and not isinstance(result, returntype):
+        if isinstance(returntype, (type, tuple)) and not isinstance(result, returntype):
             raise TypeCheckError(ret_error_fmt.format(returntype, result.__class__))
         
         return result
